#
# spec file for package python-zope.testrunner
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor test%{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
%{?sle15_python_module_pythons}
Name:           python-zope.testrunner%{psuffix}
Version:        6.6.1
Release:        2.1
Summary:        Zope testrunner script
License:        ZPL-2.1
URL:            https://github.com/zopefoundation/zope.testrunner
Source:         https://files.pythonhosted.org/packages/source/z/zope.testrunner/zope_testrunner-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  %{python_module zope.exceptions}
BuildRequires:  %{python_module zope.interface}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-setuptools
Requires:       python-zope.exceptions
Requires:       python-zope.interface
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module zope.testing}
BuildRequires:  %{python_module zope.testrunner = %{version}}
BuildRequires:  %{pythons}
%endif
%python_subpackages

%description
This package provides a flexible test runner with layer support.

%prep
%autosetup -p1 -n zope_testrunner-%{version}
find -size 0 -delete

%build
%pyproject_wheel

%install
%if !%{with test}
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%python_clone -a %{buildroot}%{_bindir}/zope-testrunner
%endif

%if %{with test}
%check
%{python_expand #
$python -m zope.testrunner --test-path=src -vv
}
%endif

%if !%{with test}
%post
%python_install_alternative zope-testrunner

%postun
%python_uninstall_alternative zope-testrunner

%files %{python_files}
%license LICENSE.md
%doc README.rst
%python_alternative %{_bindir}/zope-testrunner
%{python_sitelib}/zope/testrunner
%{python_sitelib}/zope.testrunner-%{version}-py*-nspkg.pth
%{python_sitelib}/zope[_.]testrunner-%{version}.dist-info
%endif

%changelog
* Tue Apr  1 2025 Markéta Machová <mmachova@suse.com>
- Make it compatible with older setuptools
* Thu Mar 27 2025 Steve Kowalik <steven.kowalik@suse.com>
- Normalize metadata directory name.
* Mon Jan 20 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 6.6.1
  * Make signatures in ``tb_format`` Python 3.12+ compatible (#186)
* Mon Oct 28 2024 Dirk Müller <dmueller@suse.com>
- update to 6.6:
  * Make tests compatible with Python 3.13 + add support for that
    version.
  * Drop support for Python 3.7.
* Fri Oct  4 2024 Steve Kowalik <steven.kowalik@suse.com>
- Add missing psuffix to name for multibuild.
* Wed Aug 21 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 6.5:
  * unittest.TestCase.subTest support (#91).
  * remove support for setup.py's test command. Support for this command has
    been dropped by modern setuptools versions and correspondingly has been
    removed from most zopefoundation packages; zope.testrunner now follows.
  * setup.py's ftest command is now only supported when the used setuptools
    version still supports test.
* Thu Mar 14 2024 Dirk Müller <dmueller@suse.com>
- update to 6.4:
  * Add PEP 440 support (implicit namespaces).
  * Fix XML tests when running in distribution resp. separately.
  * Exit cleanly when using the test runner --version argument.
  * Add new --xml <path> option to write JUnit-like XML reports.
    Code comes from collective.xmltestreport, but be aware that
    here --xml is not a boolean, but expects a path! (#148).
  * Add support for Python 3.13a3.
* Sat Jan 13 2024 Ben Greiner <code@bnavigator.de>
- Run the test suite with itself like it is meant to be
  * fixes Python 3.12 test failures
- Setuptools is a runtime requirement (for egg testing support)
* Tue Jan  2 2024 Dirk Müller <dmueller@suse.com>
- update to 6.2.1:
  * Work around Python 3.12.1+ no longer calling startTest for
    skipped tests
* Mon Dec 11 2023 Dirk Müller <dmueller@suse.com>
- update to 6.2:
  * Add support for Python 3.12.
  * Update code and tests to ``python-subunit >= 1.4.3`` thus
    requiring at least this version.
* Fri Jun  9 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Mon Apr  3 2023 pgajdos@suse.com
- version update to 6.0
  * - Drop support for Python 2.7, 3.5, 3.6.
- python-six is not required
* Tue Dec 13 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 5.6
  * Add support for Python 3.11.
  * Inline a small part of random.Random.shuffle which was deprecated in Python 3.9 and removed in 3.11 (#119).
  * Don’t trigger post mortem debugger for skipped tests. ( #141).
* Sat Dec  3 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 5.5.1
  * Fix: let --at-level=level with level <= 0 run the tests at all levels (rather than at no level) #138.
* Mon Sep 19 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- updated spec to include
  Requires(post): update-alternatives
  Requires(postun):update-alternatives
* Fri Sep 16 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- version update to 5.5.0
  * Use sys._current_frames (rather than threading.enumerate) as base for new thread detection, fixes #130.
  * New option --gc-after-test. It calls for a garbage collection after each test and can be used to track down
    ResourceWarning``s and cyclic garbage. With ``rv = gc.collect(), ! is output on verbosity level 1 when rv is
    non zero (i.e. when cyclic structures have been released), [``*rv*]`` on higher verbosity levels and a detailed
    cyclic garbage analysis on verbosity level 4+. For details, see #133.
  * Allow the filename for the logging configuration to be specified via the envvar ZOPE_TESTRUNNER_LOG_INI.
    If not defined, the configuration continues to be locked for in file log.ini of the current working directory.
    Remember the logging configuration file in envvar ZOPE_TESTRUNNER_LOG_INI to allow spawned child processes to
    recreate the logging configuration. For details, see #134.
- version update to 5.4.0
  * Improve --help documentation for --package-path option (#121).
  * Do not disable existing loggers during logsupport initialization (#120).
  * Fix tests with testtools >= 2.5.0 (#125).
  * Add support for Python 3.10.
* Tue Oct  5 2021 pgajdos@suse.com
- version update to 5.3.0
  - Add support for Python 3.9.
  - Fix `package init file missing` warning
    (`#112 <https://github.com/zopefoundation/zope.testrunner/pull/112>`_).
  - Make standard streams provide a `buffer` attribute on Python 3 when using
    `--buffer` or testing under subunit.
- %%check: use %%pyunittest rpm macro
* Tue Jul 21 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 5.2
  * Add support for Python 3.8.
  * When a layer is run in a subprocess, read its stderr in a thread to avoid
    a deadlock if its stderr output (containing failing and erroring test IDs)
    overflows the capacity of a pipe
* Wed Oct 30 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 5.1:
  * Recover more gracefully when layer setUp or tearDown fails, producing useful subunit output.
  * Prevent a spurious warning from the --require-unique option if the --module option was not used.
  * Add optional buffering of standard output and standard error during tests, requested via the --buffer option or enabled by default for subunit.
  * Fix incorrect failure counts in per-layer summary output, broken in 4.0.1.
* Mon Apr  8 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 5.0
  * Fix test failures and deprecation warnings occurring when
    using Python 3.8a1.
  * Drop support for Python 3.4.
  4.9*
  * Fix AssertionError in _DummyThread.isAlive on Python 3.
  * Drop support for Python 3.3.
  * Add support for Python 3.7.
  * Remove untested support for the --pychecker option.
  * Update the command line interface to use argparse instead of
    optparse.
  * Use ipdb instead of pdb for post-mortem debugging if available.
  * Add a –require-unique option to check for duplicate test IDs.
  * Reintroduce optional support for subunit.
  * Handle string in exception values when formatting chained
    exceptions.
  4.8*
  * Enable DeprecationWarning earlier, when discovering test
    modules.
  * Automatically enable DeprecationWarning when running tests.
- Launch tests using multibuild.
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Thu Jun 29 2017 aloisio@gmx.com
- Added missing requires for update-alternatives
* Fri Jun 23 2017 aloisio@gmx.com
- Update to 4.7.0
  * Drop all support for ``subunit``.
  4.6.0:
  * Make the ``subunit`` support purely optional: applications
    which have been getting the dependencies via
    ``zope.testrunner`` should either add
    ``zope.testrunner[subunit]`` to their ``install_requires`` or
    else depend directly on ``python-subunit``.
  * New option ``--ignore-new-thread=<regexp>`` to suppress
    "New thread(s)" warnings.
  * Support Python 3.6.
  4.5.1:
  * Fixed: Using the ``-j`` option to run tests in multiple
    processes caused tests that used the ``multiprocessing``
    package to hang (because the testrunner replaced ``sys.stdin``
    with an unclosable object).
  * Drop conditional dependency on ``unittest2`` (redundant after
    dropping support for Python 2.6).
  4.5.0:
  * Stop tests for all layers when test fails/errors when started
    with -x/--stop-on-error
    (`#37 <https://github.com/zopefoundation/zope.testrunner/pull/37>`_).
  * Drop support for Python 2.6 and 3.2.
  4.4.10:
  * Add support for Python 3.5
    (`#31 <https://github.com/zopefoundation/zope.testrunner/pull/31>`_).
  * Insert extra paths (from ``--path``) to the front of sys.argv
    (`#32 <https://github.com/zopefoundation/zope.testrunner/issues/32>`_).
  4.4.9:
  * When using ``-j``, parallelize all the tests, including the
    first test layer
    (`#28 <https://github.com/zopefoundation/zope.testrunner/issues/28>`_).
- Converted to single-spec
* Mon Aug 15 2016 toddrme2178@gmail.com
- Fix update-alternatives implementation.
* Fri May 15 2015 benoit.monin@gmx.fr
- update to version 4.4.8:
  * Support skipped tests in subunit output
  * More efficient test filtering
- additional changes from version 4.4.7:
  * Work around a bug in PyPy3’s curses module (#24).
- additional changes from version 4.4.6:
  * Restore support for instance-based test layers that regressed
    in 4.4.5 (#20).
- additional changes from version 4.4.5:
  * Sort related layers close to each other to reduce the number of
    unnecessary teardowns (fixes #14).
  * Run the unit test layer first (fixes LP #497871).
- additional changes from version 4.4.4:
  * When looking for the right location of test code, start with
    longest location paths first. This fixes problems with nested
    code locations.
- additional changes from version 4.4.3:
  * Added support for Python 3.4.
- additional changes from version 4.4.2:
  * Drop support for Python 3.1.
  * Fix post-mortem debugging when a non-printable exception
    happens (#8).
- add runtime requirements python-six, python-zope.exceptions,
  python-zope.interface
- update the test requirements (still commented out, tests fail)
- fix update-alternatives
* Sat Nov  8 2014 Led <ledest@gmail.com>
- fix bashism in pre script
* Thu Nov 14 2013 p.drouand@gmail.com
- Add update-alternative support
* Wed Nov 13 2013 p.drouand@gmail.com
- Update to version 4.4.1
  + Updated boostrap.py to version 2.2.
  + Fix nondeterministic test failures on Python 3.3
  + Tear down layers after post_mortem debugging is finished.
  + Fix tests that write to source directory, it might be read-only.
- Changes from 4.4.0
  + Fix tests selection when the negative "!" pattern is used several times
    (LP #1160965)
  +  Moved tests into a 'tests' subpackage.
  + Made python -m zope.testrunner work again.
  + Support 'skip' feature of unittest2 (which became the new unittest in Python 2.7).
  + Better diagnostics when communication with subprocess fails
    (https://github.com/zopefoundation/zope.testrunner/issues/5).
  + Do not break subprocess execution when the test suite changes the working
    directory (https://github.com/zopefoundation/zope.testrunner/issues/6).
  + Count test module import errors as errors (LP #1026576).
- Add python-unittest2 and python-zope.interface commented BuildRequires;
  these are new requirements for test but there are still broken
- Add fdupes BuildRequires and use fdupes to remove duplicate files
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Fri Mar 15 2013 speilicke@suse.com
- Initial version
